# Define you views here

"""
from flask import current_app as app

@app.route('/')
def index():
	return 'Hello from %s' % app.config.SERVICE_NAME
"""
